/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "Exception.h"

#include <memory>

namespace digidoc
{

EXP_DIGIDOC std::string appInfo();
EXP_DIGIDOC void initialize(const std::string &appInfo = "");
EXP_DIGIDOC void terminate();
EXP_DIGIDOC std::string version();

class Document;
class Signature;
class Signer;

class EXP_DIGIDOC ADoc
{
public:
	enum DocumentType
	{
		UnknownType = 0,
		BDocType = 1,
		DDocType = 2
	};

	virtual ~ADoc() {}
	virtual void save() throw(IOException, BDocException) = 0;
	virtual void saveTo(const std::string &path) throw(IOException, BDocException) = 0;
	virtual void addDocument(const Document& document) throw(BDocException) = 0;
	virtual Document getDocument(unsigned int id) const throw(BDocException) = 0;
	virtual void removeDocument(unsigned int id) throw(BDocException) = 0;
	virtual unsigned int documentCount() const = 0;
	virtual DocumentType documentType() const;
	virtual void addSignature(const std::vector<unsigned char> &signature) throw(BDocException) = 0;
	unsigned int newSignatureId() const;
	virtual const Signature* getSignature(unsigned int id) const throw(BDocException) = 0;
	virtual void removeSignature(unsigned int id) throw(BDocException) = 0;
	virtual unsigned int signatureCount() const = 0;
	virtual void sign(Signer* signer) throw(BDocException) = 0;
	virtual std::vector<unsigned char> getFileDigest( unsigned int id ) throw(BDocException) = 0;
};

}
