/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "Exception.h"

namespace digidoc
{
    /**
     * TODO: implement and add description
     */
    class EXP_DIGIDOC Conf
    {

      public:
          struct OCSPConf { std::string issuer, url, cert; };
          Conf() {}
          virtual ~Conf() {}
          static void init(Conf *conf);
          static bool isInitialized();
          static Conf* getInstance();
          static void destroy();

          virtual int getLogLevel() const;
          virtual std::string getLogFile() const;
          virtual std::string getDigestUri() const;
          virtual std::string getSignatureUri() const;
          virtual std::string getManifestXsdPath() const;
          virtual std::string getXadesXsdPath() const;
          virtual std::string getDsigXsdPath() const;
          virtual std::string getPKCS11DriverPath() const;
          virtual OCSPConf getOCSP(const std::string &issuer) const;
          virtual std::string getCertStorePath() const;
          virtual std::string getProxyHost() const;
          virtual std::string getProxyPort() const;
          virtual std::string getProxyUser() const;
          virtual std::string getProxyPass() const;
          virtual std::string getPKCS12Cert() const;
          virtual std::string getPKCS12Pass() const;
          virtual bool getPKCS12Disable() const;

          virtual void setProxyHost( const std::string &host ) throw(IOException) = 0;
          virtual void setProxyPort( const std::string &port ) throw(IOException) = 0;
          virtual void setProxyUser( const std::string &user ) throw(IOException) = 0;
          virtual void setProxyPass( const std::string &pass ) throw(IOException) = 0;
          virtual void setPKCS12Cert( const std::string &cert ) throw(IOException) = 0;
          virtual void setPKCS12Pass( const std::string &pass ) throw(IOException) = 0;
          virtual void setPKCS12Disable( bool disable ) throw(IOException) = 0;

          virtual void setOCSP(const std::string &issuer, const std::string &url, const std::string &cert) throw(IOException) = 0;

      private:
          Conf( const Conf& conf );
          Conf& operator= ( const Conf& conf );

          static Conf *INSTANCE;
          static const OCSPConf ocsplist[];
    };
}
