/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "Exception.h"

namespace digidoc
{
    class Digest;
    /**
     * Document wrapper for signed file in BDOC container.
     *
     * @author Janari Põld
     */
    class EXP_DIGIDOC Document
    {

      public:
          Document(const std::string &filepath, const std::string &mediaType);
          Document(const std::string &filename, const std::string &filepath, const std::string &mediaType, const std::string &id = "");
          std::string getId() const;
          std::string getFileName() const;
          std::string getFilePath() const;
          std::string getMediaType() const;
          unsigned long getSize() const throw(IOException);
          std::vector<unsigned char> calcDigest(Digest* calc) throw(IOException);
          void saveAs(const std::string& path) throw(IOException);

      protected:
          std::string id, filename, filepath, mediaType;
          std::vector<unsigned char> digest;

    };
}
