/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "Signature.h"

#include "BDoc.h"

namespace digidoc
{
    class EXP_DIGIDOC SignatureBES : public Signature
    {

      public:
          SignatureBES(unsigned int id, const BDoc &bdoc);
          SignatureBES(const std::string& path, const BDoc &bdoc) throw(SignatureException);
          virtual ~SignatureBES();
          virtual std::string getMediaType() const;
          WeakParameters isWeak() const;
          virtual void validateOffline() const throw(SignatureException);
          virtual CertStatus validateOnline() const throw(SignatureException);

          static const std::string MEDIA_TYPE;

      protected:
          std::vector<unsigned char> prepareSignedInfo(Signer *singer) throw(SignatureException, SignException);
          virtual void sign(Signer* signer) throw(SignatureException, SignException);

          const BDoc &bdoc;

      private:
          SignatureBES& operator=( SignatureBES const& that ); // undefine default

          // offline checks
          void checkSignature() const throw(SignatureException);
          void checkSignedInfo() const throw(SignatureException);
          void checkSignatureMethod() const throw(SignatureException);
          void checkReferences() const throw(SignatureException);
          void checkSignatureValue() const throw(SignatureException);
		  void checkSigningCertificate() const throw(SignatureException);
          void checkKeyInfo() const throw(SignatureException); // RSAKeyValue and X509Certificate
          void checkQualifyingProperties() const throw(SignatureException);
          void checkSignedSignatureProperties() const throw(SignatureException);

          bool isReferenceToSigProps(const digidoc::dsig::ReferenceType& refType) const throw(SignatureException);
          void checkReferenceToSigProps(const digidoc::dsig::ReferenceType& refType) const throw(SignatureException);
          void checkReferencesToDocs(dsig::SignedInfoType::ReferenceSequence& refSeq) const throw(SignatureException);
          void checkDocumentRefDigest(Document& doc, const std::string& documentFileName, const dsig::ReferenceType& refType) const throw(SignatureException);

    };
}
