/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "SignatureBES.h"


namespace digidoc
{

class EXP_DIGIDOC SignatureTM: public digidoc::SignatureBES
{
public:
    SignatureTM(unsigned int id, const BDoc &_bdoc);
    SignatureTM(const std::string& path, const BDoc &_bdoc) throw(SignatureException);
    virtual ~SignatureTM();
    virtual std::string getMediaType() const;
    std::vector<unsigned char> getNonce() const;
    X509Cert getOCSPCertificate() const;
    std::string getProducedAt() const;
    std::string getResponderID() const;
    void getRevocationOCSPRef(std::vector<unsigned char>& data, std::string& digestMethodUri) const throw(SignatureException);
    virtual void validateOffline() const throw(SignatureException);

    static const std::string MEDIA_TYPE;
protected:
    virtual void sign(Signer* signer) throw(SignatureException, SignException);
    void notarize() throw(SignatureException, SignException);
    void addCertificateValue(const std::string& certId, const X509Cert& x509);
private:
    void createTMProperties();
    void setOCSPCertificate(const X509Cert& x509);
    void setCACertificate(const X509Cert& x509);
    void setOCSPResponseValue(const std::vector<unsigned char>& data);

    void setCompleteRevocationRefs(const std::string& responderName, const std::string& digestMethodUri,
            const std::vector<unsigned char>& ocspResponseHash, const struct tm& producedAt );

    std::vector<unsigned char> getOCSPResponseValue() const;
    xades::UnsignedPropertiesType::UnsignedSignaturePropertiesOptional& unsignedSignatureProperties() const throw(SignatureException);
};

}
