/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "Conf.h"

namespace digidoc
{

class XmlConfPrivate;
class EXP_DIGIDOC XmlConf: public Conf
{
public:
    static void initialize();
    XmlConf() throw(IOException);
    XmlConf(const std::string& path) throw(IOException);
    virtual ~XmlConf();

    virtual int getLogLevel() const;
    virtual std::string getLogFile() const;
    virtual std::string getDigestUri() const;
    virtual std::string getSignatureUri() const;
    virtual std::string getManifestXsdPath() const;
    virtual std::string getXadesXsdPath() const;
    virtual std::string getDsigXsdPath() const;
    virtual std::string getPKCS11DriverPath() const;
    virtual OCSPConf getOCSP(const std::string &issuer) const;
    virtual std::string getCertStorePath() const;
    virtual std::string getProxyHost() const;
    virtual std::string getProxyPort() const;
    virtual std::string getProxyUser() const;
    virtual std::string getProxyPass() const;
    virtual std::string getPKCS12Cert() const;
    virtual std::string getPKCS12Pass() const;
    virtual bool getPKCS12Disable() const;

	static std::string getUserConfDir();
    static std::string getDefaultConfDir();

    virtual void setProxyHost( const std::string &host ) throw(IOException);
    virtual void setProxyPort( const std::string &port ) throw(IOException);
    virtual void setProxyUser( const std::string &user ) throw(IOException);
    virtual void setProxyPass( const std::string &pass ) throw(IOException);
    virtual void setPKCS12Cert( const std::string &cert ) throw(IOException);
    virtual void setPKCS12Pass( const std::string &pass ) throw(IOException);
    virtual void setPKCS12Disable( bool disable ) throw(IOException);

    virtual void setOCSP(const std::string &issuer, const std::string &url, const std::string &cert) throw(IOException);

private:
	XmlConfPrivate *d;
};

}
