/*
 * libdigidocpp
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#pragma once

#include "../../Exception.h"

#ifdef WIN32 //hack for win32 build
#undef X509_NAME
#endif
#include <openssl/x509.h>

namespace digidoc
{
    /**
     * Wrapper for OpenSSL X509 certificate structure.
     */
    class EXP_DIGIDOC X509Cert
    {

      public:
          enum KeyUsage
          {
            DigitalSignature = 0,
            NonRepudiation,
            KeyEncipherment,
            DataEncipherment,
            KeyAgreement,
            KeyCertificateSign,
            CRLSign,
            EncipherOnly,
            DecipherOnly
          };

          X509Cert();
          X509Cert(X509* cert) throw(IOException);
          X509Cert(const std::vector<unsigned char> &bytes) throw(IOException);
          X509Cert(const X509Cert& copy) throw(IOException);
          ~X509Cert();
          static X509* copyX509(X509* cert) throw(IOException);
          static X509* loadX509(const std::string& path) throw(IOException);

          int getPaddingSize() const throw(IOException);
          std::vector<unsigned char> encodeDER() const throw(IOException);
          std::string getSerial() const throw(IOException);
          X509_NAME* getIssuerNameAsn1() const;
          std::string getIssuerName(const std::string &obj = "") const throw(IOException);
          std::vector<KeyUsage> getKeyUsage() const throw(IOException);
          std::vector<std::string> getCertificatePolicies() const throw(IOException);
          std::string getSubjectName(const std::string &obj = "") const throw(IOException);
          std::vector<unsigned char> getRsaModulus() const throw(IOException);
          std::vector<unsigned char> getRsaExponent() const throw(IOException);

          X509* getX509() const throw(IOException);
          X509* handle() const;
          bool isValid() const throw(IOException);
          bool verify() const throw(IOException);

          int compareIssuerToString(const std::string &name) const throw(IOException);

          X509Cert& operator=(const X509Cert& copy) throw(IOException);
          bool operator ==(const X509Cert &other) const;

      private:
          EVP_PKEY* getPublicKey() const throw(IOException);
          std::string toString(X509_NAME *name, const std::string &obj) const throw(IOException);

          X509* cert;
    };
}
